# Generated by roxygen2: do not edit by hand

S3method(coef,svem_model)
S3method(plot,svem_binomial)
S3method(plot,svem_model)
S3method(plot,svem_significance_test)
S3method(predict,svem_cv)
S3method(predict,svem_model)
S3method(print,bigexp_formula)
S3method(print,bigexp_spec)
S3method(print,svem_significance_test)
S3method(print,svem_thompson_batch)
export(SVEMnet)
export(bigexp_formula)
export(bigexp_prepare)
export(bigexp_terms)
export(bigexp_train)
export(forward_aicc)
export(glmnet_with_cv)
export(predict_cv)
export(svem_export_candidates_csv)
export(svem_forward)
export(svem_ij_variance)
export(svem_nonzero)
export(svem_random_table_multi)
export(svem_score_random)
export(svem_select_from_score_table)
export(svem_significance_test_parallel)
export(svem_thompson_batch)
export(svem_wmt_multi)
export(with_bigexp_contrasts)
import(ggplot2)
importFrom(cluster,daisy)
importFrom(cluster,pam)
importFrom(gamlss,gamlss)
importFrom(gamlss,gamlss.control)
importFrom(gamlss.dist,SHASHo)
importFrom(glmnet,cv.glmnet)
importFrom(glmnet,glmnet)
importFrom(lhs,maximinLHS)
importFrom(lhs,randomLHS)
importFrom(parallel,clusterCall)
importFrom(parallel,makeCluster)
importFrom(parallel,parLapplyLB)
importFrom(parallel,stopCluster)
importFrom(stats,IQR)
importFrom(stats,aggregate)
importFrom(stats,as.formula)
importFrom(stats,coef)
importFrom(stats,complete.cases)
importFrom(stats,delete.response)
importFrom(stats,lm)
importFrom(stats,median)
importFrom(stats,model.frame)
importFrom(stats,model.matrix)
importFrom(stats,model.response)
importFrom(stats,na.pass)
importFrom(stats,plogis)
importFrom(stats,predict)
importFrom(stats,qlogis)
importFrom(stats,quantile)
importFrom(stats,rgamma)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,terms)
importFrom(stats,var)
importFrom(utils,combn)
importFrom(utils,head)
importFrom(utils,tail)
